@@ -13,11 +13,11 @@ Weather::YR - Object-oriented interface to Yr.no's weather service.
 
 =head1 VERSION
 
-Version 0.37.
+Version 0.38.
 
 =cut
 
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 
 =head1 SYNOPSIS
 
@@ -44,7 +44,7 @@ our $VERSION = '0.37';
     my $now = $yr->location_forecast->now;
 
     say "It's " . $now->temperature->celsius . "C outside.";
-    say "Weather status: " . $now->temperature->precipitation->symbol->text;
+    say "Weather status: " . $now->precipitation->symbol->text;
 
     # (*) "Right now" is actually lying, as the data from Yr is always
     #     a _forecast_, ie. what the weather will be like. The now()
